@@ -21,7 +21,7 @@ from contextlib import contextmanager
 import eventlet.pools
 from eventlet.green.httplib import CannotSendRequest
 
-from swift.common.utils import TRUE_VALUES, urlparse
+from swift.common.utils import TRUE_VALUES
 from swift.common import client
 from swift.common import direct_client
 
@@ -43,7 +43,7 @@ class Bench(object):
         self.user = conf.user
         self.key = conf.key
         self.auth_url = conf.auth
-        self.use_proxy = conf.use_proxy in TRUE_VALUES
+        self.use_proxy = conf.use_proxy.lower() in TRUE_VALUES
         if self.use_proxy:
             url, token = client.get_auth(self.auth_url, self.user, self.key)
             self.token = token
@@ -105,7 +105,6 @@ class Bench(object):
 
     def run(self):
         pool = eventlet.GreenPool(self.concurrency)
-        events = []
         self.beginbeat = self.heartbeat = time.time()
         self.heartbeat -= 13    # just to get the first report quicker
         self.failures = 0
@@ -125,7 +124,7 @@ class BenchController(object):
         self.logger = logger
         self.conf = conf
         self.names = []
-        self.delete = conf.delete in TRUE_VALUES
+        self.delete = conf.delete.lower() in TRUE_VALUES
         self.gets = int(conf.num_gets)
 
     def run(self):
