@@ -45,15 +45,18 @@ seconds on /v1/AUTH_account/container/object::
     expires = int(time() + 60)
     path = '/v1/AUTH_account/container/object'
     key = 'mykey'
-    hmac_body = '%s\\n%s\\n%s\\n%s' % (method, expires, path, key)
+    hmac_body = '%s\\n%s\\n%s' % (method, expires, path)
     sig = hmac.new(key, hmac_body, sha1).hexdigest()
 
-Let's say the sig ends up equaling ee796f3a89cf82ef7a36ac75fed54b83
-and expires ends up 1323479485. Then, for example, the website could
-provide a link to::
+Be certain to use the full path, from the /v1/ onward.
+
+Let's say the sig ends up equaling
+da39a3ee5e6b4b0d3255bfef95601890afd80709 and expires ends up
+1323479485. Then, for example, the website could provide a link to::
 
     https://swift-cluster.example.com/v1/AUTH_account/container/object?
-    temp_url_sig=ee796f3a89cf82ef7a36ac75fed54b83&temp_url_expires=1323479485
+    temp_url_sig=da39a3ee5e6b4b0d3255bfef95601890afd80709&
+    temp_url_expires=1323479485
 
 Any alteration of the resource path or query arguments would result
 in 401 Unauthorized. Similary, a PUT where GET was the allowed method
@@ -243,6 +246,7 @@ class TempURL(object):
         self._clean_incoming_headers(env)
         env['swift.authorize'] = lambda req: None
         env['swift.authorize_override'] = True
+        env['REMOTE_USER'] = '.wsgi.tempurl'
 
         def _start_response(status, headers, exc_info=None):
             headers = self._clean_outgoing_headers(headers)
@@ -253,7 +257,7 @@ class TempURL(object):
                         already = True
                         break
                 if not already:
-                    headers.append(('Content-Disposition', 
+                    headers.append(('Content-Disposition',
                         'attachment; filename=%s' %
                             (quote(basename(env['PATH_INFO'])))))
             return start_response(status, headers, exc_info)
@@ -329,6 +333,7 @@ class TempURL(object):
                     newenv[name] = env[name]
             newenv['swift.authorize'] = lambda req: None
             newenv['swift.authorize_override'] = True
+            newenv['REMOTE_USER'] = '.wsgi.tempurl'
             key = [None]
 
             def _start_response(status, response_headers, exc_info=None):
