@@ -465,6 +465,8 @@ def drop_privileges(user):
     :param user: User name to change privileges to
     """
     user = pwd.getpwnam(user)
+    if os.geteuid() == 0:
+        os.setgroups([])
     os.setgid(user[3])
     os.setuid(user[2])
     try:
@@ -1115,3 +1117,23 @@ def listdir(path):
         if err.errno != errno.ENOENT:
             raise
     return []
+
+
+def streq_const_time(s1, s2):
+    """Constant-time string comparison.
+
+    :params s1: the first string
+    :params s2: the second string
+
+    :return: True if the strings are equal.
+
+    This function takes two strings and compares them.  It is intended to be
+    used when doing a comparison for authentication purposes to help guard
+    against timing attacks.
+    """
+    if len(s1) != len(s2):
+        return False
+    result = 0
+    for (a, b) in zip(s1, s2):
+        result |= ord(a) ^ ord(b)
+    return result == 0
