@@ -105,7 +105,8 @@ class AuditorWorker(object):
                 self.errors = 0
                 self.bytes_processed = 0
             time_auditing += (now - loop_time)
-        elapsed = time.time() - begin
+        # Avoid divide by zero during very short runs
+        elapsed = (time.time() - begin) or 0.000001
         self.logger.info(_(
             'Object audit (%(type)s) "%(mode)s" mode '
             'completed: %(elapsed).02fs. Total quarantined: %(quars)d, '
@@ -204,7 +205,10 @@ class ObjectAuditor(Daemon):
         if parent:
             kwargs['zero_byte_fps'] = zbo_fps or self.conf_zero_byte_fps
         while True:
-            self.run_once(**kwargs)
+            try:
+                self.run_once(**kwargs)
+            except (Exception, Timeout):
+                self.logger.exception(_('ERROR auditing'))
             self._sleep()
 
     def run_once(self, *args, **kwargs):
