@@ -56,9 +56,11 @@ class FakeMemcache(object):
 class FakeApp(object):
 
     def __init__(self, status_headers_body_iter=None):
+        self.calls = 0
         self.get_c4_called = False
 
     def __call__(self, env, start_response):
+        self.calls += 1
         if env['PATH_INFO'] == '/':
             return Response(status='404 Not Found')(env, start_response)
         elif env['PATH_INFO'] == '/v1':
@@ -129,7 +131,9 @@ class FakeApp(object):
                            'x-container-meta-web-listings': 't',
                            'x-container-meta-web-listings-css': 'listing.css'})
         elif env['PATH_INFO'] == '/v1/a/c4/one.txt':
-            return Response(status='200 Ok', body='1')(env, start_response)
+            return Response(status='200 Ok',
+                headers={'x-object-meta-test': 'value'},
+                body='1')(env, start_response)
         elif env['PATH_INFO'] == '/v1/a/c4/two.txt':
             return Response(status='503 Service Unavailable')(env,
                                                               start_response)
@@ -187,7 +191,7 @@ class FakeApp(object):
             headers.update({'X-Container-Object-Count': '11',
                             'X-Container-Bytes-Used': '73741',
                             'X-Container-Read': '.r:*',
-                            'Content-Type': 'application/json; charset=utf8'})
+                            'Content-Type': 'application/json; charset=utf-8'})
             body = '''
                 [{"name":"subdir/1.txt",
                   "hash":"5f595114a4b3077edfac792c61ca4fe4", "bytes":20,
@@ -204,14 +208,14 @@ class FakeApp(object):
             headers.update({'X-Container-Object-Count': '11',
                             'X-Container-Bytes-Used': '73741',
                             'X-Container-Read': '.r:*',
-                            'Content-Type': 'application/json; charset=utf8'})
+                            'Content-Type': 'application/json; charset=utf-8'})
             body = '[]'
         elif env['PATH_INFO'] == '/v1/a/c3' and env['QUERY_STRING'] == \
                 'limit=1&format=json&delimiter=/&limit=1&prefix=subdirz/':
             headers.update({'X-Container-Object-Count': '11',
                             'X-Container-Bytes-Used': '73741',
                             'X-Container-Read': '.r:*',
-                            'Content-Type': 'application/json; charset=utf8'})
+                            'Content-Type': 'application/json; charset=utf-8'})
             body = '''
                 [{"name":"subdirz/1.txt",
                   "hash":"5f595114a4b3077edfac792c61ca4fe4", "bytes":20,
@@ -224,7 +228,7 @@ class FakeApp(object):
                             'X-Container-Bytes-Used': '73741',
                             'X-Container-Read': '.r:*',
                             'X-Container-Web-Listings': 't',
-                            'Content-Type': 'application/json; charset=utf8'})
+                            'Content-Type': 'application/json; charset=utf-8'})
             body = '''
                 [{"name":"subdir/1.txt",
                   "hash":"5f595114a4b3077edfac792c61ca4fe4", "bytes":20,
@@ -236,7 +240,7 @@ class FakeApp(object):
         elif 'format=json' in env['QUERY_STRING']:
             headers.update({'X-Container-Object-Count': '11',
                             'X-Container-Bytes-Used': '73741',
-                            'Content-Type': 'application/json; charset=utf8'})
+                            'Content-Type': 'application/json; charset=utf-8'})
             body = '''
                 [{"name":"401error.html",
                   "hash":"893f8d80692a4d3875b45be8f152ad18", "bytes":110,
@@ -265,7 +269,7 @@ class FakeApp(object):
                   "hash":"c85c1dcd19cf5cbac84e6043c31bb63e", "bytes":20,
                   "content_type":"text/plain",
                   "last_modified":"2011-03-24T04:27:52.734140"},
-                 {"name":"subdir/omgomg.txt",
+                 {"name":"subdir/\u2603.txt",
                   "hash":"7337d028c093130898d937c319cc9865", "bytes":72981,
                   "content_type":"text/plain",
                   "last_modified":"2011-03-24T04:27:52.735460"},
@@ -283,10 +287,10 @@ class FakeApp(object):
         else:
             headers.update({'X-Container-Object-Count': '11',
                             'X-Container-Bytes-Used': '73741',
-                            'Content-Type': 'text/plain; charset=utf8'})
+                            'Content-Type': 'text/plain; charset=utf-8'})
             body = '\n'.join(['401error.html', '404error.html', 'index.html',
                               'listing.css', 'one.txt', 'subdir/1.txt',
-                              'subdir/2.txt', 'subdir/omgomg.txt', 'subdir2',
+                              'subdir/2.txt', u'subdir/\u2603.txt', 'subdir2',
                               'subdir3/subsubdir/index.html', 'two.txt'])
         return Response(status='200 Ok', headers=headers,
                         body=body)(env, start_response)
@@ -295,7 +299,8 @@ class FakeApp(object):
 class TestStaticWeb(unittest.TestCase):
 
     def setUp(self):
-        self.test_staticweb = staticweb.filter_factory({})(FakeApp())
+        self.app = FakeApp()
+        self.test_staticweb = staticweb.filter_factory({})(self.app)
 
     def test_app_set(self):
         app = FakeApp()
@@ -475,6 +480,8 @@ class TestStaticWeb(unittest.TestCase):
         self.assert_('</style>' not in resp.body)
         self.assert_('<link' in resp.body)
         self.assert_('listing.css' in resp.body)
+        self.assertEquals(resp.headers['content-type'],
+                          'text/html; charset=UTF-8')
 
     def test_container4onetxt(self):
         resp = Request.blank(
@@ -505,6 +512,15 @@ class TestStaticWeb(unittest.TestCase):
         resp = Request.blank('/v1/a/c7/').get_response(self.test_staticweb)
         self.assertEquals(resp.status_int, 404)
 
+    def test_subrequest_once_if_possible(self):
+        resp = Request.blank(
+                '/v1/a/c4/one.txt').get_response(self.test_staticweb)
+        self.assertEquals(resp.status_int, 200)
+        self.assertEquals(resp.headers['x-object-meta-test'], 'value')
+        self.assertEquals(resp.body, '1')
+        self.assertEquals(self.app.calls, 1)
+        
+
 
 if __name__ == '__main__':
     unittest.main()
